package down.to.chat.neighbor;

import down.to.chat.R;
import down.to.chat.activities.FullViewActivity;
import down.to.chat.enums.Availability;
import down.to.chat.fragments.UserFragmentBase;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

/**
 * Fragment representing a neighbor. Used to view ones' self as if you were a 
 * neighbor
 * 
 * @author Matthew
 */
public class ViewFragment extends UserFragmentBase implements OnClickListener {
	
	/**
	 * Neighbor information is passed thru a bundle and state is not associated
	 * with the class
	 * @param neighbor this fragment represents
	 * @return the new fragment representing the input neighbor
	 */
	public static ViewFragment newInstance(Neighbor neighbor) {
		ViewFragment nf = new ViewFragment();
		nf.setNeighbor(neighbor);
		return nf;
	}
	
	@Override
	public View onCreateView( LayoutInflater inflater, ViewGroup container, 
			Bundle savedInstanceState) {
		if( container == null ){
			// copied from example, avoids building the object if it never
			// gets shown.
			return null;
		}
		// initialize 
		View neighborView = inflater.inflate(R.layout.neighbor_view, container, 
				false);
		// set name
		TextView nameView = (TextView) neighborView.findViewById(R.id.name);
		String name = getNeighbor().getName();
		if( name == null ) {
			name = "Name Unknown";
		}
		nameView.setText(name);
		
		// set image
		ImageView neighborImage = (ImageView) neighborView.findViewById(
				R.id.neighbor_image);
		
		neighborImage.setOnClickListener(this);
		Bitmap photo = getNeighbor().getPreview(); 
		if( photo == null ) {
			photo = BitmapFactory.decodeResource(getActivity().
					getResources(),	R.drawable.ic_action_user);
		}
		neighborImage.setImageBitmap(photo);
		
		// set background color
		View neighborHolder = neighborView.findViewById(R.id.neighbor_holder);
		neighborHolder.setBackgroundColor(Availability.getColor(getNeighbor()
				.getAvailability()));

		return neighborView;
	}

	@Override
	public void onClick(View v) {
		if( v.getId() == R.id.neighbor_image ) {
			FullViewActivity.launch(getNeighbor(), getActivity());
		}
		
	}
}

