package down.to.chat.photo;

import down.to.chat.user.EditFragment;
import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.media.FaceDetector;
import android.media.FaceDetector.Face;
import android.os.Bundle;
import android.widget.Toast;

/**
 * Handle all operations related to taking and editing pictures.
 * 
 * @author Matthew
 */
public class PhotoManager {
	
	// action types
	public static int PHOTO_TAKE_ACTION = 1;
	public static int PHOTO_CROP_ACTION = 2;
	
	// cahce of full image between actions to take photo and crop.
	Bitmap cachedFullImage;
	
	/**
	 * Handle the result of photo take action. Starts a crop action where the
	 * user will crop the image a preview square.
	 * @param caller calling activity
	 * @param data intent holding the result information from photo-take
	 */
	public void handleTaken(Activity caller, Intent data) {
		Intent cropIntent = new Intent("com.android.camera.action.CROP");
	    //indicate image type and Uri
		cropIntent.setDataAndType(data.getData(), "image/*");
		
		// store the full image so we can zoom in.
		cachedFullImage = (Bitmap)  data.getExtras().get("data");
		
		//set crop properties
		cropIntent.putExtra("crop", "true");
		//indicate aspect of desired crop
		cropIntent.putExtra("aspectX", 1);
		cropIntent.putExtra("aspectY", 1);
		//retrieve data on return
		cropIntent.putExtra("return-data", true);
		//start the activity - we handle returning in onActivityResult
		caller.startActivityForResult(cropIntent, PHOTO_CROP_ACTION);
	}
	
	/**
	 * Handle the result of photo crop action. save it to the fragment.
	 * @param data result intent holding result data
	 * @param editFrag fragment that will need to be updated with the result.
	 */
	public void handleCrop( Activity caller, Intent data, EditFragment editFrag ){
	    Bundle extras = data.getExtras();
	    Bitmap userImage = (Bitmap) extras.get("data");
	    userImage = convertTo565(userImage);
	    
	    
		// convert to even width for face detector
		if( userImage.getWidth() % 2 == 1)
			userImage = Bitmap.createScaledBitmap(userImage,userImage.getWidth()-1,
					userImage.getHeight()-1, false);

		// detect faces
		FaceDetector faceDetector = new FaceDetector( userImage.getWidth(), 
				userImage.getHeight(), 1);
		Face[] faces = new Face[1];
		faceDetector.findFaces(userImage, faces);
		
		// if we find a face store i
		if( faces.length > 0 && faces[0] != null ) {
			editFrag.setPreview(userImage,cachedFullImage);
		} else {
			Toast.makeText(caller, "Preview needs to have a face." , 
					Toast.LENGTH_SHORT ).show();
		}
	}
	
	/**
	 * To do face recognition we need to convert to to a RGB_565 format bitmap
	 * @param original bitmap base
	 * @return a 565 version of the input bitmap
	 */
	private Bitmap convertTo565( Bitmap original ) {
		if( !original.getConfig().equals(Bitmap.Config.RGB_565) ) {
			// need to convert to RGB_565 for face detector
		    Bitmap convertedBitmap = Bitmap.createBitmap(original.getWidth(), 
		    		original.getHeight(), Bitmap.Config.RGB_565);
		    Canvas canvas = new Canvas(convertedBitmap);
		    canvas.drawBitmap(original, 0, 0, null);
		    return convertedBitmap;
		} else {
			return original;
		}
	}
	
}
