package down.to.chat.user;

import down.to.chat.R;
import down.to.chat.enums.Availability;
import down.to.chat.fragments.UserFragmentBase;
import down.to.chat.neighbor.Neighbor;
import down.to.chat.photo.PhotoManager;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.provider.MediaStore;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageButton;
import android.widget.Spinner;
import android.widget.TextView;

/**
 * Fragment representing user data with ability to manipulate it.
 * 
 * Data update flow:
 * user enters in form -> hits save -> written to User -> update hooks called
 *  -> update hooks update neighbor -> fragment is drawn based on neighbor.
 * 
 * For photos:
 * user takes picture -> update neighbor -> hits save -> etc
 * 
 * @author Matthew
 *
 */
public class EditFragment extends UserFragmentBase implements OnClickListener {
	
	// Fragment UI elements
	private View neighborView;
	private TextView nameView;
	private ImageButton photoView;
	private Spinner availSpinner;
	 
	/**
	 * Neighbor information is passed thru a bundle and state is not associated
	 * with the class
	 * @param neighbor this fragment represents
	 * @return the new fragment representing the input neighbor
	 */
	public static EditFragment newInstance(Neighbor neighbor) {
		EditFragment uf = new EditFragment();
		uf.setNeighbor(neighbor);
		return uf;
	}
	
	@Override
	public View onCreateView( LayoutInflater inflater, ViewGroup container, 
			Bundle savedInstanceState) {
		if( container == null ){
			// copied from example, avoids building the object if it never
			// gets shown.
			return null;
		}
		// initialize 
		if( neighborView == null ) {
			neighborView = inflater.inflate(R.layout.user_view, container, 
				false);
		}
		
		// set name
		if( nameView == null ) {
			nameView = (TextView) neighborView.findViewById(R.id.name);
		}
		String name = getNeighbor().getName();
		if( name == null ) {
			name = "Name Unknown";
		}
		nameView.setText(name);
		
		// set image
		if ( photoView == null ) {
			photoView = (ImageButton) neighborView.findViewById(
				R.id.neighbor_image_button);
		}
		Bitmap photo = getNeighbor().getPreview(); 
		if( photo == null ) {
			photo = BitmapFactory.decodeResource(getActivity().
					getResources(),	R.drawable.ic_action_user);
		}
		photoView.setImageBitmap(photo);
		photoView.setOnClickListener(this);
		
		
		// set spinner
		if( availSpinner == null ) {
			availSpinner = (Spinner) neighborView.findViewById(
				R.id.availability_spinner);
		}
		ArrayAdapter<Availability> adapter = new ArrayAdapter<Availability>(
				getActivity(), android.R.layout.simple_spinner_item);
		adapter.setDropDownViewResource(
				android.R.layout.simple_spinner_dropdown_item);
		adapter.addAll(Availability.values());
		availSpinner.setAdapter(adapter);
		Availability userAvailability = getNeighbor().getAvailability();
		
		int availIndex = adapter.getPosition(userAvailability);
		availSpinner.setSelection(availIndex);
		
		// set background color
		View neighborHolder = neighborView.findViewById(R.id.neighbor_holder);
		neighborHolder.setBackgroundColor(Availability.getColor(getNeighbor()
				.getAvailability()));
		
		return neighborView;
	}

	/**
	 * Set the images after being edited. 
	 * @param preview 
	 * @param fullsize
	 */
	public void setPreview( Bitmap preview, Bitmap fullsize ) {
		photoView.setImageBitmap(preview);
		getNeighbor().setPreview(preview);
		getNeighbor().setPhoto(fullsize);
	}
	
	/**
	 * Save the values stored in user fragment. Set the values in the User 
	 * singleton.
	 */
	@Override 
	protected void doBeforeTransition() {
		User user = User.get();
		Context context = getActivity();
		
		// set with user
		user.setName(nameView.getText().toString(), context);
		user.setAvailability((Availability) availSpinner.getSelectedItem(), 
				context);
		user.setPhoto(getNeighbor().getPhoto(), getNeighbor().getPreview(),
				context);
	}

	@Override
	public void onClick(View v) {
		// launch activity to take image when clicking image button
		if( photoView.equals( v )) {
			Intent takePictureIntent = new Intent(
					MediaStore.ACTION_IMAGE_CAPTURE);
			getActivity().startActivityForResult(takePictureIntent, 
					PhotoManager.PHOTO_TAKE_ACTION);
		}
	}

}
